OC.L10N.register(
    "dav",
    {
    "Calendar" : "日曆",
    "Tasks" : "工作項目",
    "Personal" : "個人",
    "{actor} created calendar {calendar}" : "{actor} 建立了日曆 {calendar}",
    "You created calendar {calendar}" : "您建立了日曆 {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} 刪除了日曆 {calendar}",
    "You deleted calendar {calendar}" : "您刪除了日曆 {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} 更新了日曆 {calendar}",
    "You updated calendar {calendar}" : "您更新了日曆 {calendar}",
    "{actor} restored calendar {calendar}" : "{actor} 復原了日曆 {calendar}",
    "You restored calendar {calendar}" : "您復原了日曆 {calendar}",
    "You shared calendar {calendar} as public link" : "您將 {calendar} 日曆以公開連結分享",
    "You removed public link for calendar {calendar}" : "您刪除了 {calendar} 的公開分享連結",
    "{actor} shared calendar {calendar} with you" : "{actor} 與您分享了 {calendar} 日曆",
    "You shared calendar {calendar} with {user}" : "您與 {user} 分享了 {calendar} 日曆",
    "{actor} shared calendar {calendar} with {user}" : "{actor} 與 {user} 分享了日曆 {calendar}",
    "{actor} unshared calendar {calendar} from you" : "{actor} 停止與您分享日曆 {calendar}",
    "You unshared calendar {calendar} from {user}" : "您停止與 {user} 分享日曆 {calendar}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} 停止與 {user} 分享日曆 {calendar}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} 停止與他們自己分享日曆 {calendar}",
    "You shared calendar {calendar} with group {group}" : "您與群組 {group} 分享了日曆 {calendar}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} 與群組 {group} 分享了日曆 {calendar}",
    "You unshared calendar {calendar} from group {group}" : "您已停止與群組 {group} 分享日曆 {calendar}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} 已停止與群組 {group} 分享日曆 {calendar}",
    "Untitled event" : "未命名活動",
    "{actor} created event {event} in calendar {calendar}" : "{actor} 在日曆 {calendar} 中建立了 {event} 活動",
    "You created event {event} in calendar {calendar}" : "您在日曆 {calendar} 中建立了 {event} 活動",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} 在日曆 {calendar} 中刪除了 {event} 活動",
    "You deleted event {event} from calendar {calendar}" : "您在日曆 {calendar} 中刪除了 {event} 活動",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} 在日曆 {calendar} 中更新了 {event} 活動",
    "You updated event {event} in calendar {calendar}" : "您在日曆 {calendar} 中刪除了 {event} 活動",
    "{actor} moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "{actor} 將事件 {event} 從行事曆 {sourceCalendar} 移動至行事曆 {targetCalendar}",
    "You moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "您將事件 {event} 從行事曆 {sourceCalendar} 移動至行事曆 {targetCalendar}",
    "{actor} restored event {event} of calendar {calendar}" : "{actor} 復原了日曆 {calendar} 中的活動 {event}",
    "You restored event {event} of calendar {calendar}" : "您復原了日曆 {calendar} 中的活動 {event}",
    "Busy" : "忙碌",
    "{actor} created to-do {todo} in list {calendar}" : "{actor} 在清單 {calendar} 中建立了待辦事項 {todo}",
    "You created to-do {todo} in list {calendar}" : "您在清單 {calendar} 中建立了待辦事項 {todo}",
    "{actor} deleted to-do {todo} from list {calendar}" : "{actor} 從清單 {calendar} 中刪除了待辦事項 {todo}",
    "You deleted to-do {todo} from list {calendar}" : "您從清單 {calendar} 中刪除了待辦事項 {todo}",
    "{actor} updated to-do {todo} in list {calendar}" : "{actor} 在清單 {calendar} 中更新了待辦事項 {todo}",
    "You updated to-do {todo} in list {calendar}" : "您在清單 {calendar} 中更新了待辦事項 {todo}",
    "{actor} solved to-do {todo} in list {calendar}" : "{actor} 在清單 {calendar} 中解決了待辦事項 {todo}",
    "You solved to-do {todo} in list {calendar}" : "您在清單 {calendar} 中解決了待辦事項 {todo}",
    "{actor} reopened to-do {todo} in list {calendar}" : "{actor} 在清單 {calendar} 中重新開啟了待辦事項 {todo}",
    "You reopened to-do {todo} in list {calendar}" : "您在清單 {calendar} 中重新開啟了待辦事項 {todo}",
    "{actor} moved to-do {todo} from list {sourceCalendar} to list {targetCalendar}" : "{actor} 將待辦事項 {todo} 從清單 {sourceCalendar} 移動到清單 {targetCalendar}",
    "You moved to-do {todo} from list {sourceCalendar} to list {targetCalendar}" : "您將待辦事項 {todo} 從清單 {sourceCalendar} 移動到清單 {targetCalendar}",
    "Calendar, contacts and tasks" : "日曆、通訊錄與工作項目",
    "A <strong>calendar</strong> was modified" : "一個<strong>日曆</strong>被更動",
    "A calendar <strong>event</strong> was modified" : "一個日曆<strong>活動</strong>被更動",
    "A calendar <strong>to-do</strong> was modified" : "已修改一個行事曆<strong>待辦事項</strong>",
    "Contact birthdays" : "聯絡人生日",
    "Death of %s" : "%s 逝世",
    "Untitled calendar" : "未命名日曆",
    "Calendar:" : "日曆：",
    "Date:" : "日期：",
    "Where:" : "地點：",
    "Description:" : "描述：",
    "_%n year_::_%n years_" : ["%n年"],
    "_%n month_::_%n months_" : ["%n月"],
    "_%n day_::_%n days_" : ["%n天"],
    "_%n hour_::_%n hours_" : ["%n小時"],
    "_%n minute_::_%n minutes_" : ["%n分鐘"],
    "%s (in %s)" : "%s（在 %s）",
    "%s (%s ago)" : "%s（%s 前）",
    "Calendar: %s" : "日曆：%s",
    "Date: %s" : "日期：%s",
    "Description: %s" : "描述：%s",
    "Where: %s" : "地點：%s",
    "%1$s via %2$s" : "%1$s 由 %2$s",
    "In a %1$s on %2$s for the entire day" : "%1$s 的 %2$s 整天",
    "In a %1$s on %2$s between %3$s - %4$s" : "%1$s 的 %2$s 於 %3$s - %4$s 之間",
    "In %1$s %2$s on %3$s for the entire day" : "%1$s %2$s 的 %3$s 整天",
    "In %1$s %2$s on %3$s between %4$s - %5$s" : "%1$s %2$s 的 %3$s 於 %4$s - %5$s 之間",
    "Could not generate when statement" : "無法產生 when 陳述",
    "Every Day for the entire day" : "每天一整天",
    "Every Day for the entire day until %1$s" : "每天一整天，直到 %1$s",
    "Every Day between %1$s - %2$s" : "每天於 %1$s - %2$s 之間",
    "Every Day between %1$s - %2$s until %3$s" : "每天於 %1$s - %2$s 之間，直到 %3$s",
    "Every %1$d Days for the entire day" : "每 %1$d 天整天",
    "Every %1$d Days for the entire day until %2$s" : "每 %1$d 天整天，直到 %2$s",
    "Every %1$d Days between %2$s - %3$s" : "每 %1$d 天於 %2$s - %3$s 之間",
    "Every %1$d Days between %2$s - %3$s until %4$s" : "每 %1$d 天於 %2$s - %3$s 之間，直到 %4$s",
    "Could not generate event recurrence statement" : "無法產生事件重複陳述",
    "Every Week on %1$s for the entire day" : "每週於 %1$s 整天",
    "Every Week on %1$s for the entire day until %2$s" : "每週於 %1$s 整天，直到 %2$s",
    "Every Week on %1$s between %2$s - %3$s" : "每週於 %1$s，在  %2$s - %3$s 之間",
    "Every Week on %1$s between %2$s - %3$s until %4$s" : "每週於 %1$s，在  %2$s - %3$s 之間，直到 %4$s",
    "Every %1$d Weeks on %2$s for the entire day" : "每 %1$d 週於 %2$s 整天",
    "Every %1$d Weeks on %2$s for the entire day until %3$s" : "每 %1$d 週於 %2$s 整天，直到 %3$s",
    "Every %1$d Weeks on %2$s between %3$s - %4$s" : "每 %1$d 週於 %2$s，在 %3$s - %4$s 之間",
    "Every %1$d Weeks on %2$s between %3$s - %4$s until %5$s" : "每 %1$d 週於 %2$s，在 %3$s - %4$s 之間，直到 %5$s",
    "Every Month on the %1$s for the entire day" : "每個月於 %1$s 整天",
    "Every Month on the %1$s for the entire day until %2$s" : "每個月於 %1$s 整天，直到 %2$s",
    "Every Month on the %1$s between %2$s - %3$s" : "每個月於 %1$s，在  %2$s - %3$s 之間",
    "Every Month on the %1$s between %2$s - %3$s until %4$s" : "每個月於 %1$s，在  %2$s - %3$s 之間，直到 %4$s",
    "Every %1$d Months on the %2$s for the entire day" : "每 %1$d 個月於 %2$s 整天",
    "Every %1$d Months on the %2$s for the entire day until %3$s" : "每 %1$d 個月於 %2$s 整天，直到 %3$s",
    "Every %1$d Months on the %2$s between %3$s - %4$s" : "每 %1$d 個月於 %2$s，在 %3$s - %4$s 之間",
    "Every %1$d Months on the %2$s between %3$s - %4$s until %5$s" : "每 %1$d 個月於 %2$s，在 %3$s - %4$s 之間，直到 %5$s",
    "Every Year in %1$s on the %2$s for the entire day" : "每年於 %1$s 的 %2$s 整天",
    "Every Year in %1$s on the %2$s for the entire day until %3$s" : "每年於 %1$s 的 %2$s 整天，直到 %3$s",
    "Every Year in %1$s on the %2$s between %3$s - %4$s" : "每年於 %1$s 的 %2$s，在 %3$s - %4$s 之間",
    "Every Year in %1$s on the %2$s between %3$s - %4$s until %5$s" : "每年於 %1$s 的 %2$s，在 %3$s - %4$s 之間，直到 %5$s",
    "Every %1$d Years in %2$s on the %3$s for the entire day" : "每 %1$d 年於 %2$s 的 %3$s 整天",
    "Every %1$d Years in %2$s on the %3$s for the entire day until %4$s" : "每 %1$d 年於 %2$s 的 %3$s 整天，直到 %4$s",
    "Every %1$d Years in %2$s on the %3$s between %4$s - %5$s" : "每 %1$d 年於 %2$s 的 %3$s，在 %4$s - %5$s 之間",
    "Every %1$d Years in %2$s on the %3$s between %4$s - %5$s until %6$s" : "每 %1$d 年於 %2$s 的 %3$s，在 %4$s - %5$s 之間，直到 %6$s",
    "On specific dates for the entire day until %1$s" : "在特定日期的整天，直到 %1$s",
    "On specific dates between %1$s - %2$s until %3$s" : "在 %1$s - %2$s 之間的特定日期，直到 %3$s",
    "In a %1$s on %2$s" : "在 %1$s 的 %2$s",
    "In a %1$s on %2$s then on %3$s" : "在 %1$s 的 %2$s，然後 %3$s",
    "In a %1$s on %2$s then on %3$s and %4$s" : "在 %1$s 的 %2$s，然後 %3$s 與 %4$s",
    "In %1$s %2$s on %3$s" : "在 %1$s %2$s 的 %3$s",
    "In %1$s %2$s on %3$s then on %4$s" : "在 %1$s %2$s 的 %3$s，然後 %4$s",
    "In %1$s %2$s on %3$s then on %4$s and %5$s" : "在 %1$s %2$s 的 %3$s，然後 %4$s 與 %5$s",
    "Could not generate next recurrence statement" : "無法產生下一個重複陳述",
    "Cancelled: %1$s" : "已取消：%1$s",
    "\"%1$s\" has been canceled" : "「%1$s」已取消",
    "Re: %1$s" : "回覆：%1$s",
    "%1$s has accepted your invitation" : "%1$s 已接受您的邀請",
    "%1$s has tentatively accepted your invitation" : "%1$s 暫時接受了您的邀請",
    "%1$s has declined your invitation" : "%1$s 已婉拒您的邀請",
    "%1$s has responded to your invitation" : "%1$s 已回應您的邀請",
    "Invitation updated: %1$s" : "邀請已更新：%1$s",
    "%1$s updated the event \"%2$s\"" : "%1$s 已更新事件：「%2$s」",
    "Invitation: %1$s" : "邀請：%1$s",
    "%1$s would like to invite you to \"%2$s\"" : "%1$s 想邀請您加入「%2$s」",
    "Organizer:" : "組織者：",
    "Attendees:" : "參與者：",
    "Title:" : "標題：",
    "When:" : "時間：",
    "Location:" : "地點：",
    "Link:" : "連結：",
    "Occurring:" : "發生：",
    "Accept" : "接受",
    "Decline" : "拒絕",
    "More options …" : "更多選項……",
    "More options at %s" : "%s 有更多選項",
    "Monday" : "週一",
    "Tuesday" : "週二",
    "Wednesday" : "週三",
    "Thursday" : "週四",
    "Friday" : "週五",
    "Saturday" : "週六",
    "Sunday" : "週日",
    "January" : "一月",
    "February" : "二月",
    "March" : "三月",
    "April" : "四月",
    "May" : "五月",
    "June" : "六月",
    "July" : "七月",
    "August" : "八月",
    "September" : "九月",
    "October" : "十月",
    "November" : "十一月",
    "December" : "十二月",
    "First" : "第一個",
    "Second" : "第二",
    "Third" : "第三",
    "Fourth" : "第四",
    "Fifty" : "五十",
    "Last" : "最後",
    "Second Last" : "倒數第二",
    "Third Last" : "倒數第三",
    "Fourth Last" : "倒數第四",
    "Fifty Last" : "倒數五十",
    "Contacts" : "聯絡人",
    "{actor} created address book {addressbook}" : "{actor} 建立了通訊錄 {addressbook}",
    "You created address book {addressbook}" : "您建立了通訊錄 {addressbook}",
    "{actor} deleted address book {addressbook}" : "{actor} 刪除了通訊錄 {addressbook}",
    "You deleted address book {addressbook}" : "您刪除了通訊錄 {addressbook}",
    "{actor} updated address book {addressbook}" : "{actor} 更新了通訊錄 {addressbook}",
    "You updated address book {addressbook}" : "您更新了通訊錄 {addressbook}",
    "{actor} shared address book {addressbook} with you" : "{actor} 與您分享了通訊錄 {addressbook}",
    "You shared address book {addressbook} with {user}" : "您與 {user} 分享了通訊錄 {addressbook}",
    "{actor} shared address book {addressbook} with {user}" : "{actor} 與 {user} 分享了通訊錄 {addressbook}",
    "{actor} unshared address book {addressbook} from you" : "{actor} 取消與您分享通訊錄 {addressbook}",
    "You unshared address book {addressbook} from {user}" : "您取消與 {user} 分享的通訊錄 {addressbook}",
    "{actor} unshared address book {addressbook} from {user}" : "{actor} 取消與 {user} 分享通訊錄 {addressbook}",
    "{actor} unshared address book {addressbook} from themselves" : "{actor} 取消與他們自己分享的通訊錄 {addressbook}",
    "You shared address book {addressbook} with group {group}" : "您與群組 {group} 分享了通訊錄 {addressbook}",
    "{actor} shared address book {addressbook} with group {group}" : "{actor} 與群組 {group} 分享了通訊錄 {addressbook}",
    "You unshared address book {addressbook} from group {group}" : "您取消與群組 {group} 分享的通訊錄 {addressbook}",
    "{actor} unshared address book {addressbook} from group {group}" : "{actor} 取消與群組 {group} 分享的通訊錄 {addressbook}",
    "{actor} created contact {card} in address book {addressbook}" : "{actor} 在通訊錄 {addressbook} 中建立了聯絡人 {card}",
    "You created contact {card} in address book {addressbook}" : "您在通訊錄 {addressbook} 中建立了聯絡人 {card}",
    "{actor} deleted contact {card} from address book {addressbook}" : "{actor} 從通訊錄 {addressbook} 刪除了聯絡人 {card}",
    "You deleted contact {card} from address book {addressbook}" : "您從通訊錄 {addressbook} 刪除了聯絡人 {card}",
    "{actor} updated contact {card} in address book {addressbook}" : "{actor} 在通訊錄 {addressbook} 中更新了聯絡人 {card}",
    "You updated contact {card} in address book {addressbook}" : "您在通訊錄 {addressbook} 中更新了聯絡人 {card}",
    "A <strong>contact</strong> or <strong>address book</strong> was modified" : "<strong>聯絡人</strong>或<strong>通訊錄</strong>已被修改",
    "Accounts" : "帳號",
    "System address book which holds all accounts" : "包含所有帳號的系統通訊錄",
    "File is not updatable: %1$s" : "檔案無法更新：%1$s",
    "Could not write to final file, canceled by hook" : "無法寫入最終檔案，被掛勾取消",
    "Could not write file contents" : "無法寫入檔案內容",
    "_%n byte_::_%n bytes_" : ["%n 位元組"],
    "Error while copying file to target location (copied: %1$s, expected filesize: %2$s)" : "將檔案複製到目標位置時發生錯誤（已複製：%1$s，預期的檔案大小：%2$s）",
    "Expected filesize of %1$s but read (from Nextcloud client) and wrote (to Nextcloud storage) %2$s. Could either be a network problem on the sending side or a problem writing to the storage on the server side." : "預期的檔案大小為 %1$s，但讀取（從 Nextcloud 客戶端）與寫入（至 Nextcloud 儲存空間）%2$s。可能是傳送端的網路問題或是伺服器端的儲存空間寫入問題。",
    "Could not rename part file to final file, canceled by hook" : "無法將部份檔案重新命名為最終檔案，被掛勾取消",
    "Could not rename part file to final file" : "無法將部份檔案重新命名為最終檔案",
    "Failed to check file size: %1$s" : "檢查檔案大小失敗：%1$s",
    "Could not open file" : "無法開啟檔案",
    "Encryption not ready: %1$s" : "尚未準備好加密：%1$s",
    "Failed to open file: %1$s" : "開啟檔案失敗：%1$s",
    "Failed to unlink: %1$s" : "解除連結失敗：%1$s",
    "Failed to write file contents: %1$s" : "寫入檔案內容失敗：%1$s",
    "File not found: %1$s" : "找不到檔案：%1$s",
    "Invalid target path" : "無效目標路徑",
    "System is in maintenance mode." : "系統處於維護模式。",
    "Upgrade needed" : "需要升級",
    "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "您的 %s 必須要設定 HTTPS ，才能在 iOS/macOS 上使用 CalDAV 和 CardDAV。",
    "Configures a CalDAV account" : "設定一個 CalDAV 帳號",
    "Configures a CardDAV account" : "設定一個 CardDAV 帳號",
    "Events" : "活動",
    "Untitled task" : "未命名工作項目",
    "Completed on %s" : "完成於 %s",
    "Due on %s by %s" : "到期於 %s 由 %s",
    "Due on %s" : "到期於 %s",
    "DAV system address book" : "DAV 系統通訊錄",
    "No outstanding DAV system address book sync." : "沒有未完成的 DAV 系統通訊錄同步。",
    "The DAV system address book sync has not run yet as your instance has more than 1000 users or because an error occurred. Please run it manually by calling \"occ dav:sync-system-addressbook\"." : "DAV 系統通訊錄同步尚未執行，因為您的站台有超過 1000 個使用者，或是因為遇到錯誤。請透過呼叫「occ dav:sync-system-addressbook」手動執行。",
    "WebDAV endpoint" : "WebDAV 端點",
    "Could not check that your web server is properly set up to allow file synchronization over WebDAV. Please check manually." : "無法檢查您的網路伺服器是否已正確設定以允許透過 WebDAV 進行檔案同步。請手動檢查。",
    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "WebDAV 介面似乎為故障狀態，導致您的網頁伺服器無法提供檔案同步功能。",
    "Your web server is properly set up to allow file synchronization over WebDAV." : "您的網路伺服器已正確設定為允許透過 WebDAV 進行檔案同步。",
    "Migrated calendar (%1$s)" : "已導入的行事曆 (%1$s)",
    "Calendars including events, details and attendees" : "行事曆，包含事件、詳細資訊及參與者",
    "Contacts and groups" : "聯絡人與群組",
    "WebDAV" : "WebDAV",
    "First day" : "第一天",
    "Last day (inclusive)" : "最後一天（含）",
    "Out of office replacement (optional)" : "不在辦公室取代（選擇性）",
    "Name of the replacement" : "取代名稱",
    "No results." : "沒有結果。",
    "Start typing." : "開始輸入。",
    "Short absence status" : "短暫缺席狀態",
    "Long absence Message" : "長期缺席訊息",
    "Save" : "儲存",
    "Disable absence" : "停用缺席",
    "Absence saved" : "缺席時段已儲存",
    "Failed to save your absence settings" : "儲存您的缺席設定失敗",
    "Absence cleared" : "缺席時段已清除",
    "Failed to clear your absence settings" : "清除您的缺席設定失敗",
    "Time zone:" : "時區：",
    "to" : "到",
    "Delete slot" : "刪除欄位",
    "No working hours set" : "未設定工作時間",
    "Add slot" : "新增欄位",
    "Weekdays" : "週間",
    "Pick a start time for {dayName}" : "為 {dayName} 挑選開始時間",
    "Pick a end time for {dayName}" : "為 {dayName} 挑選結束時間",
    "Automatically set user status to \"Do not disturb\" outside of availability to mute all notifications." : "在忙碌時，自動將使用者狀態設定為「請勿打擾」以靜音所有通知。",
    "Failed to load availability" : "載入可用性失敗",
    "Saved availability" : "已儲存可用性",
    "Failed to save availability" : "儲存可用性失敗",
    "Availability" : "可用性",
    "If you configure your working hours, other people will see when you are out of office when they book a meeting." : "若您設定了您的工作時間，其他使用者在預約會議時就會知道您何時不在辦公室。",
    "Absence" : "缺席",
    "Configure your next absence period." : "設定您的下一個缺席時段。",
    "Calendar server" : "日曆伺服器",
    "Send invitations to attendees" : "發送邀請函給參加者",
    "Automatically generate a birthday calendar" : "自動生成生日日曆",
    "Birthday calendars will be generated by a background job." : "生日日曆將由背景作業生成。",
    "Hence they will not be available immediately after enabling but will show up after some time." : "因此，啟用後不會立即可用，但會在一段時間後顯示。",
    "Send notifications for events" : "傳送活動通知",
    "Notifications are sent via background jobs, so these must occur often enough." : "通知會透過背景作業傳送，因此這些會經常發生。",
    "Send reminder notifications to calendar sharees as well" : "也向共享行事曆傳送提醒通知",
    "Reminders are always sent to organizers and attendees." : "一律傳送提醒給舉辦者與參與者。",
    "Enable notifications for events via push" : "啟用推播活動通知",
    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "也安裝{calendarappstoreopen}日曆應用程式{linkclose}，或{calendardocopen}連結您的電腦或行動裝置以供同步 ↗{linkclose}。",
    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "請確定您正確設定了{emailopen}電子郵件伺服器{linkclose}。",
    "There was an error updating your attendance status." : "更新您的參與狀態時發生錯誤。",
    "Please contact the organizer directly." : "請直接聯絡主辦人。",
    "Are you accepting the invitation?" : "您接受邀請嗎？",
    "Tentative" : "暫定",
    "Your attendance was updated successfully." : "您的參與狀態成功更新。",
    "To-dos" : "待辦事項",
    "Time:" : "時間：",
    "Invalid chunk name" : "無效的區塊名稱",
    "Could not rename part file assembled from chunks" : "無法重新命名從區塊組合成的部份檔案",
    "If you configure your working hours, other users will see when you are out of office when they book a meeting." : "若您設定了您的工作時間，其他使用者在預約會議時就會知道您何時不在辦公室。"
},
"nplurals=1; plural=0;");
